@@ -12,6 +12,8 @@ class addAccountToProjectCmd (baseCmd):
         self.account = None
         """email to which invitation to the project is going to be sent"""
         self.email = None
+        """"""
+        self.starteventid = None
         self.required = ["projectid",]
 
 class addAccountToProjectResponse (baseResponse):
