@@ -13,8 +13,14 @@ class addNetworkServiceProviderCmd (baseCmd):
         self.physicalnetworkid = None
         """the destination Physical Network ID to bridge to"""
         self.destinationphysicalnetworkid = None
+        """"""
+        self.id = None
+        """"""
+        self.id = None
         """the list of services to be enabled for this physical network service provider"""
         self.servicelist = []
+        """"""
+        self.starteventid = None
         self.required = ["name","physicalnetworkid",]
 
 class addNetworkServiceProviderResponse (baseResponse):
