@@ -11,6 +11,8 @@ class assignToLoadBalancerRuleCmd (baseCmd):
         """the list of IDs of the virtual machine that are being assigned to the load balancer rule(i.e. virtualMachineIds=1,2,3)"""
         """Required"""
         self.virtualmachineids = []
+        """"""
+        self.starteventid = None
         self.required = ["id","virtualmachineids",]
 
 class assignToLoadBalancerRuleResponse (baseResponse):
