@@ -5,12 +5,14 @@ from deleteAccount import deleteAccountResponse
 from updateAccount import updateAccountResponse
 from disableAccount import disableAccountResponse
 from enableAccount import enableAccountResponse
+from lockAccount import lockAccountResponse
 from listAccounts import listAccountsResponse
 from markDefaultZoneForAccount import markDefaultZoneForAccountResponse
 from createUser import createUserResponse
 from deleteUser import deleteUserResponse
 from updateUser import updateUserResponse
 from listUsers import listUsersResponse
+from lockUser import lockUserResponse
 from disableUser import disableUserResponse
 from enableUser import enableUserResponse
 from getUser import getUserResponse
@@ -29,14 +31,14 @@ from rebootVirtualMachine import rebootVirtualMachineResponse
 from startVirtualMachine import startVirtualMachineResponse
 from stopVirtualMachine import stopVirtualMachineResponse
 from resetPasswordForVirtualMachine import resetPasswordForVirtualMachineResponse
-from changeServiceForVirtualMachine import changeServiceForVirtualMachineResponse
 from updateVirtualMachine import updateVirtualMachineResponse
-from recoverVirtualMachine import recoverVirtualMachineResponse
 from listVirtualMachines import listVirtualMachinesResponse
 from getVMPassword import getVMPasswordResponse
-from migrateVirtualMachine import migrateVirtualMachineResponse
-from assignVirtualMachine import assignVirtualMachineResponse
 from restoreVirtualMachine import restoreVirtualMachineResponse
+from changeServiceForVirtualMachine import changeServiceForVirtualMachineResponse
+from assignVirtualMachine import assignVirtualMachineResponse
+from migrateVirtualMachine import migrateVirtualMachineResponse
+from recoverVirtualMachine import recoverVirtualMachineResponse
 from createSnapshot import createSnapshotResponse
 from listSnapshots import listSnapshotsResponse
 from deleteSnapshot import deleteSnapshotResponse
@@ -82,6 +84,7 @@ from listPublicIpAddresses import listPublicIpAddressesResponse
 from listPortForwardingRules import listPortForwardingRulesResponse
 from createPortForwardingRule import createPortForwardingRuleResponse
 from deletePortForwardingRule import deletePortForwardingRuleResponse
+from updatePortForwardingRule import updatePortForwardingRuleResponse
 from enableStaticNat import enableStaticNatResponse
 from createIpForwardingRule import createIpForwardingRuleResponse
 from deleteIpForwardingRule import deleteIpForwardingRuleResponse
@@ -125,6 +128,7 @@ from changeServiceForRouter import changeServiceForRouterResponse
 from listRouters import listRoutersResponse
 from listVirtualRouterElements import listVirtualRouterElementsResponse
 from configureVirtualRouterElement import configureVirtualRouterElementResponse
+from createVirtualRouterElement import createVirtualRouterElementResponse
 from startSystemVm import startSystemVmResponse
 from rebootSystemVm import rebootSystemVmResponse
 from stopSystemVm import stopSystemVmResponse
@@ -291,7 +295,6 @@ from listUsageTypes import listUsageTypesResponse
 from addTrafficMonitor import addTrafficMonitorResponse
 from deleteTrafficMonitor import deleteTrafficMonitorResponse
 from listTrafficMonitors import listTrafficMonitorsResponse
-from createVirtualRouterElement import createVirtualRouterElementResponse
 from addNiciraNvpDevice import addNiciraNvpDeviceResponse
 from deleteNiciraNvpDevice import deleteNiciraNvpDeviceResponse
 from listNiciraNvpDevices import listNiciraNvpDevicesResponse
@@ -330,6 +333,11 @@ class CloudStackAPIClient:
         response = self.connection.make_request(command, response)
         return response
 
+    def lockAccount(self,command):
+        response = lockAccountResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
     def listAccounts(self,command):
         response = listAccountsResponse()
         response = self.connection.make_request(command, response)
@@ -360,6 +368,11 @@ class CloudStackAPIClient:
         response = self.connection.make_request(command, response)
         return response
 
+    def lockUser(self,command):
+        response = lockUserResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
     def disableUser(self,command):
         response = disableUserResponse()
         response = self.connection.make_request(command, response)
@@ -450,21 +463,11 @@ class CloudStackAPIClient:
         response = self.connection.make_request(command, response)
         return response
 
-    def changeServiceForVirtualMachine(self,command):
-        response = changeServiceForVirtualMachineResponse()
-        response = self.connection.make_request(command, response)
-        return response
-
     def updateVirtualMachine(self,command):
         response = updateVirtualMachineResponse()
         response = self.connection.make_request(command, response)
         return response
 
-    def recoverVirtualMachine(self,command):
-        response = recoverVirtualMachineResponse()
-        response = self.connection.make_request(command, response)
-        return response
-
     def listVirtualMachines(self,command):
         response = listVirtualMachinesResponse()
         response = self.connection.make_request(command, response)
@@ -475,8 +478,13 @@ class CloudStackAPIClient:
         response = self.connection.make_request(command, response)
         return response
 
-    def migrateVirtualMachine(self,command):
-        response = migrateVirtualMachineResponse()
+    def restoreVirtualMachine(self,command):
+        response = restoreVirtualMachineResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def changeServiceForVirtualMachine(self,command):
+        response = changeServiceForVirtualMachineResponse()
         response = self.connection.make_request(command, response)
         return response
 
@@ -485,8 +493,13 @@ class CloudStackAPIClient:
         response = self.connection.make_request(command, response)
         return response
 
-    def restoreVirtualMachine(self,command):
-        response = restoreVirtualMachineResponse()
+    def migrateVirtualMachine(self,command):
+        response = migrateVirtualMachineResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def recoverVirtualMachine(self,command):
+        response = recoverVirtualMachineResponse()
         response = self.connection.make_request(command, response)
         return response
 
@@ -715,6 +728,11 @@ class CloudStackAPIClient:
         response = self.connection.make_request(command, response)
         return response
 
+    def updatePortForwardingRule(self,command):
+        response = updatePortForwardingRuleResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
     def enableStaticNat(self,command):
         response = enableStaticNatResponse()
         response = self.connection.make_request(command, response)
@@ -930,6 +948,11 @@ class CloudStackAPIClient:
         response = self.connection.make_request(command, response)
         return response
 
+    def createVirtualRouterElement(self,command):
+        response = createVirtualRouterElementResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
     def startSystemVm(self,command):
         response = startSystemVmResponse()
         response = self.connection.make_request(command, response)
@@ -1760,11 +1783,6 @@ class CloudStackAPIClient:
         response = self.connection.make_request(command, response)
         return response
 
-    def createVirtualRouterElement(self,command):
-        response = createVirtualRouterElementResponse()
-        response = self.connection.make_request(command, response)
-        return response
-
     def addNiciraNvpDevice(self,command):
         response = addNiciraNvpDeviceResponse()
         response = self.connection.make_request(command, response)
