@@ -11,6 +11,8 @@ class configureVirtualRouterElementCmd (baseCmd):
         """Enabled/Disabled the service provider"""
         """Required"""
         self.enabled = None
+        """"""
+        self.starteventid = None
         self.required = ["id","enabled",]
 
 class configureVirtualRouterElementResponse (baseResponse):
