@@ -8,6 +8,8 @@ class createVpnGatewayCmd (baseCmd):
         """public ip address id of the vpn gateway"""
         """Required"""
         self.vpcid = None
+        """"""
+        self.starteventid = None
         self.required = ["vpcid",]
 
 class createVpnGatewayResponse (baseResponse):
