@@ -8,6 +8,8 @@ class deleteAccountCmd (baseCmd):
         """Account id"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class deleteAccountResponse (baseResponse):
