@@ -11,6 +11,8 @@ class deleteAccountFromProjectCmd (baseCmd):
         """id of the project to remove the account from"""
         """Required"""
         self.projectid = None
+        """"""
+        self.starteventid = None
         self.required = ["account","projectid",]
 
 class deleteAccountFromProjectResponse (baseResponse):
