@@ -8,6 +8,8 @@ class deleteAutoScalePolicyCmd (baseCmd):
         """the ID of the autoscale policy"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class deleteAutoScalePolicyResponse (baseResponse):
