@@ -8,6 +8,8 @@ class deleteAutoScaleVmGroupCmd (baseCmd):
         """the ID of the autoscale group"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class deleteAutoScaleVmGroupResponse (baseResponse):
