@@ -8,6 +8,8 @@ class deleteAutoScaleVmProfileCmd (baseCmd):
         """the ID of the autoscale profile"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class deleteAutoScaleVmProfileResponse (baseResponse):
