@@ -8,6 +8,8 @@ class deleteConditionCmd (baseCmd):
         """the ID of the condition."""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class deleteConditionResponse (baseResponse):
