@@ -8,6 +8,8 @@ class deleteCounterCmd (baseCmd):
         """the ID of the counter"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class deleteCounterResponse (baseResponse):
