@@ -10,6 +10,8 @@ class deleteDomainCmd (baseCmd):
         self.id = None
         """true if all domain resources (child domains, accounts) have to be cleaned up, false otherwise"""
         self.cleanup = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class deleteDomainResponse (baseResponse):
