@@ -8,6 +8,8 @@ class deleteIpForwardingRuleCmd (baseCmd):
         """the id of the forwarding rule"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class deleteIpForwardingRuleResponse (baseResponse):
