@@ -8,6 +8,8 @@ class deleteIsoCmd (baseCmd):
         """the ID of the ISO file"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         """the ID of the zone of the ISO file. If not specified, the ISO will be deleted from all the zones"""
         self.zoneid = None
         self.required = ["id",]
