@@ -8,6 +8,8 @@ class deleteLBStickinessPolicyCmd (baseCmd):
         """the ID of the LB stickiness policy"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class deleteLBStickinessPolicyResponse (baseResponse):
