@@ -8,6 +8,8 @@ class deleteLoadBalancerRuleCmd (baseCmd):
         """the ID of the load balancer rule"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class deleteLoadBalancerRuleResponse (baseResponse):
