@@ -8,6 +8,8 @@ class deleteNetworkACLCmd (baseCmd):
         """the ID of the network ACL"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class deleteNetworkACLResponse (baseResponse):
