@@ -8,6 +8,8 @@ class deleteNiciraNvpDeviceCmd (baseCmd):
         """Nicira device ID"""
         """Required"""
         self.nvpdeviceid = None
+        """"""
+        self.starteventid = None
         self.required = ["nvpdeviceid",]
 
 class deleteNiciraNvpDeviceResponse (baseResponse):
