@@ -8,6 +8,8 @@ class deletePortForwardingRuleCmd (baseCmd):
         """the ID of the port forwarding rule"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class deletePortForwardingRuleResponse (baseResponse):
