@@ -8,6 +8,8 @@ class deletePrivateGatewayCmd (baseCmd):
         """the ID of the private gateway"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class deletePrivateGatewayResponse (baseResponse):
