@@ -8,6 +8,8 @@ class deleteProjectInvitationCmd (baseCmd):
         """id of the invitation"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class deleteProjectInvitationResponse (baseResponse):
