@@ -8,6 +8,8 @@ class deleteRemoteAccessVpnCmd (baseCmd):
         """public ip address id of the vpn server"""
         """Required"""
         self.publicipid = None
+        """"""
+        self.starteventid = None
         self.required = ["publicipid",]
 
 class deleteRemoteAccessVpnResponse (baseResponse):
