@@ -8,6 +8,8 @@ class deleteSnapshotCmd (baseCmd):
         """The ID of the snapshot"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class deleteSnapshotResponse (baseResponse):
