@@ -8,6 +8,8 @@ class deleteStaticRouteCmd (baseCmd):
         """the ID of the static route"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class deleteStaticRouteResponse (baseResponse):
