@@ -11,6 +11,8 @@ class deleteTagsCmd (baseCmd):
         """Delete tag by resource type"""
         """Required"""
         self.resourcetype = None
+        """"""
+        self.starteventid = None
         """Delete tags matching key/value pairs"""
         self.tags = []
         self.required = ["resourceids","resourcetype",]
