@@ -8,6 +8,8 @@ class deleteTemplateCmd (baseCmd):
         """the ID of the template"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         """the ID of zone of the template"""
         self.zoneid = None
         self.required = ["id",]
