@@ -8,6 +8,8 @@ class deleteTrafficTypeCmd (baseCmd):
         """traffic type id"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class deleteTrafficTypeResponse (baseResponse):
