@@ -8,6 +8,8 @@ class deleteVPCCmd (baseCmd):
         """the ID of the VPC"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class deleteVPCResponse (baseResponse):
