@@ -8,6 +8,8 @@ class disableUserCmd (baseCmd):
         """Disables user by user ID."""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class disableUserResponse (baseResponse):
