@@ -1,5 +1,5 @@
 
-"""List template visibility and all accounts that have permissions to view this template."""
+"""List iso visibility and all accounts that have permissions to view this iso."""
 from baseCmd import *
 from baseResponse import *
 class listIsoPermissionsCmd (baseCmd):
