@@ -14,6 +14,8 @@ class markDefaultZoneForAccountCmd (baseCmd):
         """The Zone ID with which the account is to be marked."""
         """Required"""
         self.zoneid = None
+        """"""
+        self.starteventid = None
         self.required = ["account","domainid","zoneid",]
 
 class markDefaultZoneForAccountResponse (baseResponse):
