@@ -11,6 +11,8 @@ class removeFromLoadBalancerRuleCmd (baseCmd):
         """the list of IDs of the virtual machines that are being removed from the load balancer rule (i.e. virtualMachineIds=1,2,3)"""
         """Required"""
         self.virtualmachineids = []
+        """"""
+        self.starteventid = None
         self.required = ["id","virtualmachineids",]
 
 class removeFromLoadBalancerRuleResponse (baseResponse):
