@@ -8,6 +8,8 @@ class revokeSecurityGroupEgressCmd (baseCmd):
         """The ID of the egress rule"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class revokeSecurityGroupEgressResponse (baseResponse):
