@@ -8,6 +8,8 @@ class revokeSecurityGroupIngressCmd (baseCmd):
         """The ID of the ingress rule"""
         """Required"""
         self.id = None
+        """"""
+        self.starteventid = None
         self.required = ["id",]
 
 class revokeSecurityGroupIngressResponse (baseResponse):
