@@ -10,6 +10,8 @@ class updatePhysicalNetworkCmd (baseCmd):
         self.id = None
         """the speed for the physical network[1G/10G]"""
         self.networkspeed = None
+        """"""
+        self.starteventid = None
         """Enabled/Disabled"""
         self.state = None
         """Tag the physical network"""
