@@ -12,6 +12,8 @@ class updateProjectInvitationCmd (baseCmd):
         self.accept = None
         """account that is joining the project"""
         self.account = None
+        """"""
+        self.starteventid = None
         """list invitations for specified account; this parameter has to be specified with domainId"""
         self.token = None
         self.required = ["projectid",]
