@@ -12,6 +12,8 @@ class updateStorageNetworkIpRangeCmd (baseCmd):
         self.endip = None
         """the netmask for storage network"""
         self.netmask = None
+        """"""
+        self.starteventid = None
         """the beginning IP address"""
         self.startip = None
         """Optional. the vlan the ip range sits on"""
