@@ -10,6 +10,8 @@ class updateTrafficTypeCmd (baseCmd):
         self.id = None
         """The network name label of the physical device dedicated to this traffic on a KVM host"""
         self.kvmnetworklabel = None
+        """"""
+        self.starteventid = None
         """The network name label of the physical device dedicated to this traffic on a VMware host"""
         self.vmwarenetworklabel = None
         """The network name label of the physical device dedicated to this traffic on a XenServer host"""
