@@ -5,7 +5,7 @@ from baseResponse import *
 class updateUserCmd (baseCmd):
     def __init__(self):
         self.isAsync = "false"
-        """User id"""
+        """User uuid"""
         """Required"""
         self.id = None
         """email"""
