@@ -17,6 +17,8 @@ class uploadCustomCertificateCmd (baseCmd):
         self.name = None
         """The private key for the attached certificate."""
         self.privatekey = None
+        """"""
+        self.starteventid = None
         self.required = ["certificate","domainsuffix",]
 
 class uploadCustomCertificateResponse (baseResponse):
